function [ret,x0,str,ts,xts]=energies(t,x,u,flag);
%ENERGIES	is the M-file description of the SIMULINK system named ENERGIES.
%	The block-diagram can be displayed by typing: ENERGIES.
%
%	SYS=ENERGIES(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes ENERGIES to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling ENERGIES with a FLAG of zero:
%	[SIZES]=ENERGIES([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[151,88,1154,1004])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     'periode_orbitale')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[5,101,40,139])

add_block('built-in/MATLAB Fcn',[sys,'/','fonction eclipse'])
set_param([sys,'/','fonction eclipse'],...
		'MATLAB Fcn','eclipse(u)',...
		'position',[180,93,305,147])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'hide name',0,...
		'mat-name','temps_eclipse',...
		'buffer','10000',...
		'position',[345,50,450,70])


%     Subsystem  'Extras22'.

new_system([sys,'/','Extras22'])
set_param([sys,'/','Extras22'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras22'],...
		'Mask Display','Initialisation\net lancement',...
		'Mask Dialogue','eval(''clear;clc;energdat;'')')


%     Finished composite block 'Extras22'.

set_param([sys,'/','Extras22'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[805,500,975,556])


%     Subsystem  'Extras21'.

new_system([sys,'/','Extras21'])
set_param([sys,'/','Extras21'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras21'],...
		'Mask Display','Courbes comparaison de\nl''nergie en survie\net de l''nergie normale',...
		'Mask Dialogue','eval(''plot(temps,energie_survie,''''w'''',temps,energie_normale,''''g'''');grid;figure(gcf)'')')


%     Finished composite block 'Extras21'.

set_param([sys,'/','Extras21'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[550,500,785,566])


%     Subsystem  'Extras18'.

new_system([sys,'/','Extras18'])
set_param([sys,'/','Extras18'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras18'],...
		'Mask Display','Courbe de la\npuissance en survie',...
		'Mask Dialogue','eval(''plot(temps,puissance_survie);grid;figure(gcf)'')')


%     Finished composite block 'Extras18'.

set_param([sys,'/','Extras18'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[295,465,470,521])

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'position',[610,192,645,238])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'hide name',0,...
		'mat-name','energie_normale',...
		'buffer','10000',...
		'position',[685,199,800,231])


%     Subsystem  ['Inner',13,'Product2'].

new_system([sys,'/',['Inner',13,'Product2']])
set_param([sys,'/',['Inner',13,'Product2']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['Inner',13,'Product2/in_1']])
set_param([sys,'/',['Inner',13,'Product2/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['Inner',13,'Product2/in_2']])
set_param([sys,'/',['Inner',13,'Product2/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['Inner',13,'Product2/out_1']])
set_param([sys,'/',['Inner',13,'Product2/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['Inner',13,'Product2/Sum']])
set_param([sys,'/',['Inner',13,'Product2/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['Inner',13,'Product2/Product']])
set_param([sys,'/',['Inner',13,'Product2/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['Inner',13,'Product2']],[150,65;180,65])
add_line([sys,'/',['Inner',13,'Product2']],[95,65;120,65])
add_line([sys,'/',['Inner',13,'Product2']],[40,35;60,60])
add_line([sys,'/',['Inner',13,'Product2']],[40,100;60,70])
set_param([sys,'/',['Inner',13,'Product2']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Inner',13,'Product2']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Inner',13,'Product2'].

set_param([sys,'/',['Inner',13,'Product2']],...
		'hide name',0,...
		'position',[480,177,510,253])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','10000',...
		'position',[100,67,160,93])


%     Subsystem  ['Inner',13,'Product1'].

new_system([sys,'/',['Inner',13,'Product1']])
set_param([sys,'/',['Inner',13,'Product1']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['Inner',13,'Product1/in_1']])
set_param([sys,'/',['Inner',13,'Product1/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['Inner',13,'Product1/in_2']])
set_param([sys,'/',['Inner',13,'Product1/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['Inner',13,'Product1/out_1']])
set_param([sys,'/',['Inner',13,'Product1/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['Inner',13,'Product1/Sum']])
set_param([sys,'/',['Inner',13,'Product1/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['Inner',13,'Product1/Product']])
set_param([sys,'/',['Inner',13,'Product1/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['Inner',13,'Product1']],[150,65;180,65])
add_line([sys,'/',['Inner',13,'Product1']],[95,65;120,65])
add_line([sys,'/',['Inner',13,'Product1']],[40,35;60,60])
add_line([sys,'/',['Inner',13,'Product1']],[40,100;60,70])
set_param([sys,'/',['Inner',13,'Product1']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Inner',13,'Product1']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Inner',13,'Product1'].

set_param([sys,'/',['Inner',13,'Product1']],...
		'hide name',0,...
		'position',[550,96,580,189])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'position',[645,122,680,168])

add_block('built-in/MATLAB Fcn',[sys,'/','fonction  puissanc'])
set_param([sys,'/','fonction  puissanc'],...
		'MATLAB Fcn','puissanc(u)',...
		'Output Width','4',...
		'position',[175,244,305,296])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'position',[330,126,370,414])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'hide name',0,...
		'mat-name','puissance_normale',...
		'buffer','10000',...
		'position',[690,249,810,271])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'hide name',0,...
		'mat-name','energie_survie',...
		'buffer','10000',...
		'position',[700,129,805,161])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','puissance_survie',...
		'buffer','10000',...
		'position',[695,69,815,91])

add_block('built-in/To Workspace',[sys,'/','To Workspace8'])
set_param([sys,'/','To Workspace8'],...
		'hide name',0,...
		'mat-name','KS',...
		'buffer','10000',...
		'position',[430,292,490,318])

add_block('built-in/To Workspace',[sys,'/','To Workspace9'])
set_param([sys,'/','To Workspace9'],...
		'hide name',0,...
		'mat-name','KN',...
		'buffer','10000',...
		'position',[435,362,495,388])


%     Subsystem  'Extras17'.

new_system([sys,'/','Extras17'])
set_param([sys,'/','Extras17'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras17'],...
		'Mask Display','Courbe de la\npuissance normale',...
		'Mask Dialogue','eval(''plot(temps,puissance_normale);grid;figure(gcf)'')')


%     Finished composite block 'Extras17'.

set_param([sys,'/','Extras17'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[70,465,245,521])


%     Subsystem  'Extras20'.

new_system([sys,'/','Extras20'])
set_param([sys,'/','Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras20'],...
		'Mask Display','Courbe de\nl''nergie normale',...
		'Mask Dialogue','eval(''plot(temps,energie_normale);grid;figure(gcf)'')')


%     Finished composite block 'Extras20'.

set_param([sys,'/','Extras20'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[70,525,245,581])


%     Subsystem  'Extras19'.

new_system([sys,'/','Extras19'])
set_param([sys,'/','Extras19'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras19'],...
		'Mask Display','Courbe de\nl''nergie en survie',...
		'Mask Dialogue','eval(''plot(temps,energie_survie);grid;figure(gcf)'')')


%     Finished composite block 'Extras19'.

set_param([sys,'/','Extras19'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[295,525,470,581])


%     Subsystem  'Extras23'.

new_system([sys,'/','Extras23'])
set_param([sys,'/','Extras23'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras23'],...
		'Mask Display','Tmoin\nd''incidence\nngative en survie',...
		'Mask Dialogue','eval(''plot(temps,KS);grid;figure(gcf)'')')


%     Finished composite block 'Extras23'.

set_param([sys,'/','Extras23'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[295,590,470,661])

add_block('built-in/Integrator',[sys,'/','Integrator2'])
set_param([sys,'/','Integrator2'],...
		'position',[520,312,555,358])

add_block('built-in/To Workspace',[sys,'/','To Workspace10'])
set_param([sys,'/','To Workspace10'],...
		'hide name',0,...
		'mat-name','duree_incid_neg_survie',...
		'buffer','10000',...
		'position',[605,320,765,350])

add_block('built-in/Integrator',[sys,'/','Integrator3'])
set_param([sys,'/','Integrator3'],...
		'position',[520,417,555,463])

add_block('built-in/Note',[sys,'/',[' tmoin d''incidence <0 en mode survie survie']])
set_param([sys,'/',[' tmoin d''incidence <0 en mode survie survie']],...
		'position',[545,270,550,275])

add_block('built-in/Note',[sys,'/',['tmoin d''incidence <0 en mode normal ']])
set_param([sys,'/',['tmoin d''incidence <0 en mode normal ']],...
		'position',[545,385,550,390])

add_block('built-in/To Workspace',[sys,'/','To Workspace11'])
set_param([sys,'/','To Workspace11'],...
		'hide name',0,...
		'mat-name','duree_incid_neg_normal',...
		'buffer','10000',...
		'position',[610,428,770,452])


%     Subsystem  'Extras24'.

new_system([sys,'/','Extras24'])
set_param([sys,'/','Extras24'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras24'],...
		'Mask Display','Dure par priode\nd''incidence\nngative en survie',...
		'Mask Dialogue','eval(''plot(temps,duree_incid_neg_survie);grid;figure(gcf)'')')


%     Finished composite block 'Extras24'.

set_param([sys,'/','Extras24'],...
		'ForeGround',6,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[295,665,470,736])


%     Subsystem  'Extras26'.

new_system([sys,'/','Extras26'])
set_param([sys,'/','Extras26'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras26'],...
		'Mask Display','Dure par priode\nd''incidence\nngative en normal',...
		'Mask Dialogue','eval(''plot(temps,duree_incid_neg_normal);grid;figure(gcf)'')')


%     Finished composite block 'Extras26'.

set_param([sys,'/','Extras26'],...
		'ForeGround',6,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[70,665,245,736])


%     Subsystem  'Extras25'.

new_system([sys,'/','Extras25'])
set_param([sys,'/','Extras25'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras25'],...
		'Mask Display','Tmoin\nd''incidence\nngative en normal',...
		'Mask Dialogue','eval(''plot(temps,KN);grid;figure(gcf)'')')


%     Finished composite block 'Extras25'.

set_param([sys,'/','Extras25'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[70,585,245,656])


%     Subsystem  'Extras27'.

new_system([sys,'/','Extras27'])
set_param([sys,'/','Extras27'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras27'],...
		'Mask Display','Dure par priode\nd''une clipse',...
		'Mask Dialogue','eval(''plot(temps,temps_eclipse);grid;figure(gcf)'')')


%     Finished composite block 'Extras27'.

set_param([sys,'/','Extras27'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[555,575,730,646])

add_block('built-in/Note',[sys,'/',['Initialisation par',13,'energdat']])
set_param([sys,'/',['Initialisation par',13,'energdat']],...
		'position',[890,555,895,560])
add_line(sys,[45,120;175,120])
add_line(sys,[135,120;135,270;170,270])
add_line(sys,[310,120;320,120;320,60;340,60])
add_line(sys,[320,120;545,120])
add_line(sys,[310,270;325,270])
add_line(sys,[440,120;440,195;475,195])
add_line(sys,[515,215;605,215])
add_line(sys,[585,145;640,145])
add_line(sys,[685,145;695,145])
add_line(sys,[605,145;605,80;690,80])
add_line(sys,[650,215;680,215])
add_line(sys,[545,215;545,260;685,260])
add_line(sys,[70,120;70,80;95,80])
add_line(sys,[375,165;545,165])
add_line(sys,[375,235;475,235])
add_line(sys,[375,305;425,305])
add_line(sys,[375,375;430,375])
add_line(sys,[400,305;400,335;515,335])
add_line(sys,[560,335;600,335])
add_line(sys,[400,375;400,440;515,440])
add_line(sys,[560,440;605,440])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
